@@ -127,7 +127,6 @@ calc_tsfresh <- function(data, column_id = "id", column_sort = "timepoint", clea
     groups <- data %>%
       dplyr::select(c(.data$id, .data$group)) %>%
       dplyr::distinct()
-  } else{
   }
   
   # Load Python function
@@ -156,13 +155,24 @@ calc_tsfresh <- function(data, column_id = "id", column_sort = "timepoint", clea
                         timepoint = temp$timepoint,
                         values = temp$values)
     
+    if("group" %in% colnames(data)){
+      
+      classes <- groups %>%
+        dplyr::select(c(.data$group)) %>%
+        dplyr::mutate(id = dplyr::row_number())
+      
+      outData <- tsfresh_calculator(timeseries = temp1, column_id = column_id, column_sort = column_sort, cleanup = cleanup, classes = classes)
+    } else{
+      outData <- tsfresh_calculator(timeseries = temp1, column_id = column_id, column_sort = column_sort, cleanup = cleanup)
+    }
+    
     # Compute features and re-join back correct id labels
     
     ids2 <- ids %>%
       dplyr::select(-c(.data$id)) %>%
       dplyr::rename(id = .data$old_id)
     
-    outData <- tsfresh_calculator(timeseries = temp1, column_id = column_id, column_sort = column_sort, cleanup = cleanup) %>%
+    outData <- outData %>%
       cbind(ids2) %>%
       tidyr::gather("names", "values", -.data$id) %>%
       dplyr::mutate(method = "tsfresh")
@@ -174,9 +184,20 @@ calc_tsfresh <- function(data, column_id = "id", column_sort = "timepoint", clea
     
     ids <- unique(temp1$id)
     
+    if("group" %in% colnames(data)){
+      
+      classes <- groups %>%
+        dplyr::select(c(.data$group)) %>%
+        dplyr::mutate(id = dplyr::row_number())
+      
+      outData <- tsfresh_calculator(timeseries = temp1, column_id = column_id, column_sort = column_sort, cleanup = cleanup, clases = classes) 
+    } else{
+      outData <- tsfresh_calculator(timeseries = temp1, column_id = column_id, column_sort = column_sort, cleanup = cleanup) 
+    }
+    
     # Do calculations
     
-    outData <- tsfresh_calculator(timeseries = temp1, column_id = column_id, column_sort = column_sort, cleanup = cleanup) %>%
+    outData <- outData %>%
       dplyr::mutate(id = ids) %>%
       tidyr::gather("names", "values", -.data$id) %>%
       dplyr::mutate(method = "tsfresh")
@@ -185,7 +206,6 @@ calc_tsfresh <- function(data, column_id = "id", column_sort = "timepoint", clea
   if(c("group") %in% colnames(data)){
     outData <- outData %>%
       dplyr::inner_join(groups, by = c("id" = "id"))
-  } else{
   }
   
   message("\nCalculations completed for tsfresh.")
@@ -278,12 +298,11 @@ calc_kats <- function(data){
 #------------------- Main exported calculation function ------------
 
 #' Compute features on an input time series dataset
+#' 
 #' @importFrom rlang .data
 #' @import dplyr
 #' @importFrom tibble as_tibble
-#' @importFrom tidyr gather
-#' @importFrom tidyr pivot_longer
-#' @importFrom tidyr unnest_wider
+#' @importFrom tidyr gather pivot_longer unnest_wider
 #' @import tsibble
 #' @import Rcatch22
 #' @importFrom tsfeatures lumpiness stability max_level_shift max_var_shift max_kl_shift crossing_points flat_spots hurst compengine autocorr_features pred_features station_features dist_features scal_features embed2_incircle firstzero_ac ac_9 firstmin_ac trev_num motiftwo_entro3 binarize_mean walker_propcross localsimple_taures sampen_first sampenc std1st_der spreadrandomlocal_meantaul histogram_mode outlierinclude_mdrmd fluctanal_prop_r1 entropy tsfeatures stl_features acf_features pacf_features holt_parameters hw_parameters heterogeneity nonlinearity arch_stat
@@ -291,16 +310,16 @@ calc_kats <- function(data){
 #' @import reticulate
 #' @importFrom fabletools features
 #' @importFrom fabletools feature_set
-#' @param data a dataframe with at least 4 columns: id variable, group variable, time variable, value variable
-#' @param id_var a string specifying the ID variable to identify each time series. Defaults to \code{NULL}
-#' @param time_var a string specifying the time index variable. Defaults to \code{NULL}
-#' @param values_var a string specifying the values variable. Defaults to \code{NULL}
-#' @param group_var a string specifying the grouping variable that each unique series sits under (if one exists). Defaults to \code{NULL}
-#' @param feature_set the set of time-series features to calculate. Defaults to \code{catch22}
-#' @param catch24 a Boolean specifying whether to compute \code{catch24} in addition to \code{catch22} if \code{catch22} is one of the feature sets selected. Defaults to \code{FALSE}
-#' @param tsfresh_cleanup a Boolean specifying whether to use the in-built \code{tsfresh} relevant feature filter or not. Defaults to \code{FALSE}
-#' @param seed fixed number for R's random number generator to ensure reproducibility
-#' @return object of class dataframe that contains the summary statistics for each feature
+#' @param data \code{data.frame} with at least 4 columns: id variable, group variable, time variable, value variable
+#' @param id_var \code{string} specifying the ID variable to identify each time series. Defaults to \code{"id"}
+#' @param time_var \code{string} specifying the time index variable. Defaults to \code{"timepoint"}
+#' @param values_var \code{string} specifying the values variable. Defaults to \code{"values"}
+#' @param group_var \code{string} specifying the grouping variable that each unique series sits under (if one exists). Defaults to \code{NULL}
+#' @param feature_set \code{string} or \code{vector} of \code{string}s denoting the set of time-series features to calculate. Defaults to \code{"catch22"}
+#' @param catch24 \code{Boolean} specifying whether to compute \code{catch24} in addition to \code{catch22} if \code{catch22} is one of the feature sets selected. Defaults to \code{FALSE}
+#' @param tsfresh_cleanup \code{Boolean} specifying whether to use the in-built \code{tsfresh} relevant feature filter or not. Defaults to \code{FALSE}
+#' @param seed \code{integer} denoting a fixed number for R's random number generator to ensure reproducibility
+#' @return object of class \code{feature_calculations} that contains the summary statistics for each feature
 #' @author Trent Henderson
 #' @export
 #' @examples
@@ -313,33 +332,10 @@ calc_kats <- function(data){
 #'   seed = 123)
 #'
 
-calculate_features <- function(data, id_var = NULL, time_var = NULL, values_var = NULL, group_var = NULL,
+calculate_features <- function(data, id_var = "id", time_var = "timepoint", values_var = "values", group_var = NULL,
                                feature_set = c("catch22", "feasts", "tsfeatures", "Kats", "tsfresh", "TSFEL"), 
                                catch24 = FALSE, tsfresh_cleanup = FALSE, seed = 123){
   
-  if(is.null(id_var) || is.null(time_var) || is.null(values_var)){
-    stop("Input must be a dataframe with at least 3 columns: id, timepoint, value")
-  }
-  
-  # Make 'catch22' the default
-  
-  if(missing(feature_set)){
-    feature_set <- "catch22"
-    message("No feature set entered. Running catch22 by default.")
-  }
-  
-  if(is.null(feature_set)){
-    feature_set <- "catch22"
-    message("No feature set entered. Running catch22 by default.")
-  }
-  
-  # Seed
-  
-  if(is.null(seed) || missing(seed)){
-    seed <- 123
-    message("No argument supplied to seed, using 123 as default.")
-  }
-  
   #--------- Error catches ---------
   
   #-----------------
@@ -348,22 +344,10 @@ calculate_features <- function(data, id_var = NULL, time_var = NULL, values_var
   
   # Recode deprecated lower case from v0.3.5
   
+  feature_set = match.arg(feature_set)
   feature_set <- replace(feature_set, feature_set == "kats", "Kats")
   feature_set <- replace(feature_set, feature_set == "tsfel", "TSFEL")
   
-  # Check incorrect specifications
-  
-  the_sets <- c("catch22", "feasts", "tsfeatures", "Kats", "tsfresh", "TSFEL")
-  '%ni%' <- Negate('%in%')
-  
-  if(length(base::setdiff(feature_set, the_sets)) != 0){
-    stop("feature_set should be a single string specification or vector of 'all', 'catch22', 'feasts', 'tsfeatures', 'Kats', 'tsfresh' or 'TSFEL'.")
-  }
-  
-  if(!is.null(group_var) && !is.character(group_var)){
-    stop("group_var should be a string specifying the variable name of your grouping variable.")
-  }
-  
   #--------- Quality by ID --------
   
   data_re <- data %>%
@@ -431,7 +415,7 @@ calculate_features <- function(data, id_var = NULL, time_var = NULL, values_var
   
   if("tsfresh" %in% feature_set){
     
-    message("'tsfresh' requires a Python installation and the 'tsfresh' Python package to also be installed. Please ensure you have this working (see https://tsfresh.com for more information). You can specify which Python to use by running one of the following in your R console/script prior to calling calculate_features(): theft::init_theft(path_to_python) where path_to_python is a string specifying the location of Python with the installed libraries on your machine.")
+    message("'tsfresh' requires a Python installation and the 'tsfresh' Python package to also be installed. You can specify which Python to use by running one of the following in your R console/script prior to calling calculate_features(): theft::init_theft(python_path, venv_path) where python_path is a string specifying the location of Python and venv_path is a string specifying the location of the venv where the Python libraries are installed.")
     
     if(tsfresh_cleanup){
       cleanuper <- "Yes"
@@ -445,14 +429,14 @@ calculate_features <- function(data, id_var = NULL, time_var = NULL, values_var
   
   if("TSFEL" %in% feature_set){
     
-    message("'TSFEL' requires a Python installation and the 'TSFEL' Python package to also be installed. Please ensure you have this working (see https://TSFEL.readthedocs.io/en/latest/ for more information). You can specify which Python to use by running one of the following in your R console/script prior to calling calculate_features(): theft::init_theft(path_to_python) where path_to_python is a string specifying the location of Python with the installed libraries on your machine.")
+    message("'TSFEL' requires a Python installation and the 'TSFEL' Python package to also be installed. You can specify which Python to use by running one of the following in your R console/script prior to calling calculate_features(): theft::init_theft(python_path, venv_path) where python_path is a string specifying the location of Python and venv_path is a string specifying the location of the venv where the Python libraries are installed.")
     message("\nRunning computations for TSFEL...")
     tmp_tsfel <- calc_tsfel(data = data_re)
   }
   
   if("Kats" %in% feature_set){
     
-    message("'Kats' requires a Python installation and the 'Kats' Python package to also be installed. Please ensure you have this working (see https://facebookresearch.github.io/Kats/ for more information). You can specify which Python to use by running one of the following in your R console/script prior to calling calculate_features(): theft::init_theft(path_to_python) where path_to_python is a string specifying the location of Python with the installed libraries on your machine.")
+    message("'Kats' requires a Python installation and the 'Kats' Python package to also be installed. You can specify which Python to use by running one of the following in your R console/script prior to calling calculate_features(): theft::init_theft(python_path, venv_path) where python_path is a string specifying the location of Python and venv_path is a string specifying the location of the venv where the Python libraries are installed.")
     message("\nRunning computations for Kats...")
     tmp_kats <- calc_kats(data = data_re)
   }
@@ -487,5 +471,6 @@ calculate_features <- function(data, id_var = NULL, time_var = NULL, values_var
     tmp_all_features <- dplyr::bind_rows(tmp_all_features, tmp_kats)
   }
   
+  tmp_all_features <- structure(list(tmp_all_features), class = "feature_calculations")
   return(tmp_all_features)
 }
