@@ -594,6 +594,7 @@ clean_by_set <- function(data, themethod = NULL){
 #---------------- Main function ----------------
 
 #' Fit a classifier to feature matrix using all features or all features by set
+#' 
 #' @importFrom rlang .data as_function is_bool abort
 #' @import dplyr
 #' @import ggplot2
@@ -603,20 +604,18 @@ clean_by_set <- function(data, themethod = NULL){
 #' @importFrom purrr map map_df
 #' @importFrom janitor clean_names
 #' @importFrom caret preProcess train confusionMatrix
-#' @param data the dataframe containing the raw feature data as calculated by \code{theft::calculate_features}
-#' @param id_var a string specifying the ID variable to group data on (if one exists). Defaults to \code{"id"}
-#' @param group_var a string specifying the grouping variable that the data aggregates to. Defaults to \code{"group"}
-#' @param by_set Boolean specifying whether to compute classifiers for each feature set. Defaults to \code{FALSE}
-#' @param test_method the algorithm to use for quantifying class separation. Defaults to \code{"gaussprRadial"}
-#' @param use_balanced_accuracy a Boolean specifying whether to use balanced accuracy as the summary metric for caret model training. Defaults to \code{FALSE}
-#' @param use_k_fold a Boolean specifying whether to use k-fold procedures for generating a distribution of classification accuracy estimates. Defaults to \code{TRUE}
-#' @param num_folds an integer specifying the number of folds (train-test splits) to perform if \code{use_k_fold} is set to \code{TRUE}. Defaults to \code{10}
-#' @param use_empirical_null a Boolean specifying whether to use empirical null procedures to compute p-values. Defaults to \code{FALSE}
-#' @param null_testing_method a string specifying the type of statistical method to use to calculate p-values. Defaults to \code{model free shuffles}
-#' @param p_value_method a string specifying the method of calculating p-values. Defaults to \code{"empirical"}
-#' @param num_permutations an integer specifying the number of class label shuffles to perform if \code{use_empirical_null} is \code{TRUE}. Defaults to \code{100}
-#' @param seed fixed number for R's random number generator to ensure reproducibility
-#' @return an object of class list containing dataframe summaries of the classification models and a \code{ggplot} object if \code{by_set} is \code{TRUE}
+#' @param data the \code{feature_calculations} object containing the raw feature matrix produced by \code{calculate_features}
+#' @param by_set \code{Boolean} specifying whether to compute classifiers for each feature set. Defaults to \code{FALSE}
+#' @param test_method \code{string} specifying the algorithm to use for quantifying class separation. Defaults to \code{"gaussprRadial"}. Must be a valid \code{caret} classification model
+#' @param use_balanced_accuracy \code{Boolean} specifying whether to use balanced accuracy as the summary metric for caret model training. Defaults to \code{FALSE}
+#' @param use_k_fold \code{Boolean} specifying whether to use k-fold procedures for generating a distribution of classification accuracy estimates. Defaults to \code{TRUE}
+#' @param num_folds \code{integer} specifying the number of folds (train-test splits) to perform if \code{use_k_fold} is set to \code{TRUE}. Defaults to \code{10}
+#' @param use_empirical_null \code{Boolean} specifying whether to use empirical null procedures to compute p-values. Defaults to \code{FALSE}
+#' @param null_testing_method \code{string} specifying the type of statistical method to use to calculate p-values. Defaults to \code{model free shuffles}
+#' @param p_value_method \code{string} specifying the method of calculating p-values. Defaults to \code{"empirical"}
+#' @param num_permutations \code{integer} specifying the number of class label shuffles to perform if \code{use_empirical_null} is \code{TRUE}. Defaults to \code{100}
+#' @param seed \code{integer} denoting a fixed number for R's random number generator to ensure reproducibility
+#' @return an object of class \code{list} containing a \code{data.frame} summary of raw classification results, a \code{data.frame} summary of the test statistics, and a \code{ggplot} object if \code{by_set} is \code{TRUE}
 #' @author Trent Henderson
 #' @export
 #' @examples
@@ -630,8 +629,6 @@ clean_by_set <- function(data, themethod = NULL){
 #'   seed = 123)
 #'
 #' fit_multi_feature_classifier(featMat,
-#'   id_var = "id",
-#'   group_var = "group",
 #'   by_set = FALSE,
 #'   test_method = "gaussprRadial",
 #'   use_balanced_accuracy = FALSE,
@@ -645,143 +642,23 @@ clean_by_set <- function(data, themethod = NULL){
 #' }
 #'
 
-fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group",
-                                         by_set = FALSE, test_method = "gaussprRadial",
+fit_multi_feature_classifier <- function(data, by_set = FALSE, test_method = "gaussprRadial",
                                          use_balanced_accuracy = FALSE, use_k_fold = TRUE, num_folds = 10,
                                          use_empirical_null = FALSE, null_testing_method = c("ModelFreeShuffles", "NullModelFits"),
                                          p_value_method = c("empirical", "gaussian"), num_permutations = 100, seed = 123){
   
-  #---------- Check arguments ------------
+  stopifnot(inherits(data, "feature_calculations") == TRUE)
+  null_testing_method <- match.arg(null_testing_method)
+  p_value_method <- match.arg(p_value_method)
   
-  expected_cols_1 <- "names"
-  expected_cols_2 <- "values"
-  expected_cols_3 <- "method"
-  the_cols <- colnames(data)
-  '%ni%' <- Negate('%in%')
+  #------------- Rename columns -------------
   
-  if(expected_cols_1 %ni% the_cols){
-    stop("data should contain at least three columns called 'names', 'values', and 'method'. These are automatically produced by theft::calculate_features(). Please consider running this first and then passing the resultant dataframe to this function.")
-  }
-  
-  if(expected_cols_2 %ni% the_cols){
-    stop("data should contain at least three columns called 'names', 'values', and 'method'. These are automatically produced by theft::calculate_features(). Please consider running this first and then passing the resultant dataframe to this function.")
-  }
-  
-  if(expected_cols_3 %ni% the_cols){
-    stop("data should contain at least three columns called 'names', 'values', and 'method'. These are automatically produced by theft::calculate_features(). Please consider running this first and then passing the resultant dataframe to this function.")
-  }
-  
-  if(!is.numeric(data$values)){
-    stop("'values' column in data should be a numerical vector.")
-  }
-  
-  if(!is.null(id_var) && !is.character(id_var)){
-    stop("id_var should be a string specifying a variable in the input data that uniquely identifies each observation.")
-  }
-  
-  # Null testing options
-  
-  theoptions <- c("ModelFreeShuffles", "NullModelFits")
-  
-  if(null_testing_method == "model free shuffles"){
-    message("'model free shuffles' is deprecated, please use 'ModelFreeShuffles' instead.")
-    null_testing_method <- "ModelFreeShuffles"
-  }
-  
-  if(null_testing_method == "null model fits"){
-    message("'null model fits' is deprecated, please use 'NullModelFits' instead.")
-    null_testing_method <- "NullModelFits"
-  }
-  
-  if(is.null(null_testing_method) || missing(null_testing_method)){
-    null_testing_method <- "ModelFreeShuffles"
-    message("No argument supplied to null_testing_method. Using 'ModelFreeShuffles' as default.")
-  }
-  
-  if(length(null_testing_method) != 1){
-    stop("null_testing_method should be a single string of either 'ModelFreeShuffles' or 'NullModelFits'.")
-  }
-  
-  if(null_testing_method %ni% theoptions){
-    stop("null_testing_method should be a single string of either 'ModelFreeShuffles' or 'NullModelFits'.")
-  }
-  
-  if(null_testing_method == "ModelFreeShuffles" && num_permutations < 1000){
-    message("Null testing method 'ModelFreeShuffles' is fast. Consider running more permutations for more reliable results. N = 10000 is recommended.")
-  }
-  
-  # p-value options
-  
-  theoptions_p <- c("empirical", "gaussian")
-  
-  if(is.null(p_value_method) || missing(p_value_method)){
-    p_value_method <- "gaussian"
-    message("No argument supplied to p_value_method Using 'gaussian' as default.")
-  }
-  
-  if(length(p_value_method) != 1){
-    stop("p_value_method should be a single string of either 'empirical' or 'gaussian'.")
-  }
-  
-  if(p_value_method %ni% theoptions_p){
-    stop("p_value_method should be a single string of either 'empirical' or 'gaussian'.")
-  }
-  
-  # Seed
-  
-  if(is.null(seed) || missing(seed)){
-    seed <- 123
-    message("No argument supplied to seed, using 123 as default.")
-  }
-  
-  #------------- Renaming columns -------------
-  
-  if (is.null(id_var)){
-    stop("Data is not uniquely identifiable. Please add a unique identifier variable.")
-  }
-  
-  if(!is.null(id_var)){
-    data_id <- data %>%
-      dplyr::rename(id = dplyr::all_of(id_var),
-                    group = dplyr::all_of(group_var)) %>%
-      dplyr::select(c(.data$id, .data$group, .data$method, .data$names, .data$values))
-  }
-  
-  num_classes <- length(unique(data_id$group)) # Get number of classes in the data
+  num_classes <- length(unique(data[[1]]$group)) # Get number of classes in the data
   
   if(num_classes < 2){
     stop("Your data has less than two unique classes. At least two are required to performed classification analysis.")
   }
   
-  # Set defaults for classification method
-  
-  if((missing(test_method) || is.null(test_method))){
-    test_method <- "gaussprRadial"
-    message("test_method is NULL or missing, fitting 'gaussprRadial' by default.")
-  }
-  
-  if(length(test_method) != 1){
-    stop("test_method should be a single string specification of a classification model available in the `caret` package. 'svmLinear' or 'gaussprRadial' are recommended as starting points.")
-  }
-  
-  # Splits and shuffles
-  
-  if(use_k_fold == TRUE && !is.numeric(num_folds)){
-    stop("num_folds should be a positive integer. 10 folds is recommended.")
-  }
-  
-  if(use_empirical_null == TRUE && !is.numeric(num_permutations)){
-    stop("num_permutations should be a postive integer. A minimum of 50 permutations is recommended.")
-  }
-  
-  if(use_empirical_null == TRUE && num_permutations < 3){
-    stop("num_permutations should be a positive integer >= 3 for empirical null calculations. A minimum of 50 permutations is recommended.")
-  }
-  
-  if(use_k_fold == TRUE && num_folds < 1){
-    stop("num_folds should be a positive integer. 10 folds is recommended.")
-  }
-  
   #------------- Preprocess data --------------
   
   # NOTE: This performs NA checking and filtering by feature set to maximise features and IDs for each if `by_set = TRUE`
@@ -790,16 +667,16 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
     
     message("Assessing feature values and unique IDs for NAs by individual set.")
     
-    data_id <- unique(data_id$method) %>%
-      purrr::map_df(~ clean_by_set(data = data_id, themethod = .x))
+    data_id <- unique(data[[1]]$method) %>%
+      purrr::map_df(~ clean_by_set(data = data[[1]], themethod = .x))
     
     # Create reference set for all feature aggregation option
     
-    data_id_all <- clean_by_set(data = data_id, themethod = NULL)
+    data_id_all <- clean_by_set(data = data[[1]], themethod = NULL)
     
   } else{
     message("Assessing feature values and unique IDs for NAs using matrix of all features.")
-    data_id <- clean_by_set(data = data_id, themethod = NULL)
+    data_id <- clean_by_set(data = data[[1]], themethod = NULL)
   }
   
   #------------- Fit models -------------------
