@@ -5,15 +5,13 @@ test_that("multi feature graphics", {
   skip_on_cran()
   
   expect_equal(2, 
-               length(fit_multi_feature_classifier(feature_matrix, id_var = "id", group_var = "group",
-                                                   by_set = FALSE, test_method = "gaussprRadial", use_balanced_accuracy = TRUE,
+               length(fit_multi_feature_classifier(feature_matrix, by_set = FALSE, test_method = "gaussprRadial", use_balanced_accuracy = TRUE,
                                                    use_k_fold = FALSE, num_folds = 10, 
                                                    use_empirical_null = TRUE, null_testing_method = "ModelFreeShuffles",
                                                    p_value_method = "empirical", num_permutations = 10)))
   
   expect_equal(3, 
-               length(fit_multi_feature_classifier(feature_matrix, id_var = "id", group_var = "group",
-                                                   by_set = TRUE, test_method = "gaussprRadial", use_balanced_accuracy = TRUE,
+               length(fit_multi_feature_classifier(feature_matrix, by_set = TRUE, test_method = "gaussprRadial", use_balanced_accuracy = TRUE,
                                                    use_k_fold = FALSE, num_folds = 10, 
                                                    use_empirical_null = TRUE, null_testing_method = "ModelFreeShuffles",
                                                    p_value_method = "empirical", num_permutations = 10)))
@@ -24,15 +22,13 @@ test_that("multi feature balanced accuracy", {
   skip_on_cran()
   
   expect_equal(7, 
-               ncol(fit_multi_feature_classifier(feature_matrix, id_var = "id", group_var = "group",
-                                                   by_set = TRUE, test_method = "gaussprRadial", use_balanced_accuracy = TRUE,
-                                                   use_k_fold = FALSE, num_folds = 10, 
-                                                   use_empirical_null = TRUE, null_testing_method = "ModelFreeShuffles",
-                                                   p_value_method = "empirical", num_permutations = 10)$TestStatistics))
+               ncol(fit_multi_feature_classifier(feature_matrix, by_set = TRUE, test_method = "gaussprRadial", use_balanced_accuracy = TRUE,
+                                                 use_k_fold = FALSE, num_folds = 10, 
+                                                 use_empirical_null = TRUE, null_testing_method = "ModelFreeShuffles",
+                                                 p_value_method = "empirical", num_permutations = 10)$TestStatistics))
   
   expect_equal(5, 
-               ncol(fit_multi_feature_classifier(feature_matrix, id_var = "id", group_var = "group",
-                                                 by_set = TRUE, test_method = "gaussprRadial", use_balanced_accuracy = FALSE,
+               ncol(fit_multi_feature_classifier(feature_matrix, by_set = TRUE, test_method = "gaussprRadial", use_balanced_accuracy = FALSE,
                                                  use_k_fold = FALSE, num_folds = 10, 
                                                  use_empirical_null = TRUE, null_testing_method = "ModelFreeShuffles",
                                                  p_value_method = "empirical", num_permutations = 10)$TestStatistics))
@@ -42,16 +38,13 @@ test_that("multi feature null model fits", {
   
   skip_on_cran()
   
-  expect_equal(nrow(fit_multi_feature_classifier(feature_matrix, 
-                                                 id_var = "id", group_var = "group",
-                                                 by_set = FALSE, test_method = "gaussprRadial", use_balanced_accuracy = FALSE,
+  expect_equal(nrow(fit_multi_feature_classifier(feature_matrix, by_set = FALSE, test_method = "gaussprRadial", use_balanced_accuracy = FALSE,
                                                  use_k_fold = TRUE, num_folds = 10, 
                                                  use_empirical_null = TRUE, null_testing_method = "ModelFreeShuffles",
                                                  p_value_method = "empirical", num_permutations = 10)$RawClassificationResults),
-               nrow(fit_multi_feature_classifier(feature_matrix, 
-                                                 id_var = "id", group_var = "group",
-                                                 by_set = FALSE, test_method = "gaussprRadial", use_balanced_accuracy = FALSE,
+               
+               nrow(fit_multi_feature_classifier(feature_matrix, by_set = FALSE, test_method = "gaussprRadial", use_balanced_accuracy = FALSE,
                                                  use_k_fold = TRUE, num_folds = 10, 
-                                                 use_empirical_null = TRUE, null_testing_method = "null model fits",
+                                                 use_empirical_null = TRUE, null_testing_method = "NullModelFits",
                                                  p_value_method = "empirical", num_permutations = 10)$RawClassificationResults))
 })
